Other Material — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »

# Other Material

## Videos

These are the videos of a series dedicated to introduce the main features of PyTables in a visual and easy to grasp manner. More videos will be made available with the time:

- HDF5 is for Lovers, SciPy 2012 Tutorial: a beginer’s introduction to PyTables and HDF5.
- PyTables, part I: Introduction: HDF5 file creation, the object tree, homogeneous array storage, natural naming, working with attributes.
- PyTables, part II: Working with tables: Creation of tables with multidimensional and nested columns, and how to efficiently query them.

## Presentations

Here are the slides of some presentations about PyTables that you may find useful:

- HDF5 is for Lovers, SciPy 2012 Tutorial, July 2012, Austin, TX, USA, slides (pdf), video, exercises, solutions, and repository.
- An on-disk binary data container. Talk given at the Austin Python Meetup, Austin, TX, USA (May 2012).
- Large Data Analysis with Python. Seminar given at the German Neuroinformatics Node, Munich, Germany (November 2010).
- Highly Efficient Computations In Python: Well Beyond NumPy. Tutorial given at EuroSciPy 2010 conference in Paris, France (July 2010).
- Starving CPUs (and coping with that in PyTables). Seminar given at FOM Institute for Plasma Physics Rijnhuizen, The Netherlands (September 2009).
- On The Data Access Issue (or Why Modern CPUs Are Starving). Keynote presented at EuroSciPy 2009 conference in Leipzig, Germany (July 2009).
- An Overview of Future Improvements to OPSI. Informal talk given at the THG headquarters in Urbana-Champaign, Illinois, USA (October 2007).
- Finding Needles in a Huge DataStack. Talk given at the EuroPython 2006 Conference, held at CERN, Genève, Switzerland (July 2006).
- Presentation given at the “HDF Workshop 2005”, held at San Francisco, USA (December 2005).
- I and II Workshop in Free Software and Scientific Computing given at the Universitat Jaume I, Castelló, Spain (October 2004). In Catalan.
- Presentation given at the “SciPy Workshop 2004”, held at Caltech, Pasadena, USA (September 2004).
- Slides of presentation given at EuroPython Conference in Charleroi, Belgium (June 2003).
- Presentation for the “iParty5” held at Castelló, Spain (May 2003). In Spanish.
- Talk on PyTables given at the PyCon 2003 Convention held at Washington, USA (March 203).

## Reports

- White Paper on OPSI indexes, explaining the powerful new indexing engine in PyTables Pro.
- Performance study on how the new object tree cache introduced in PyTables 1.2 can accelerate the opening of files with a large number of objects, while being quite less memory hungry.
- Paper version of the presentation at PyCon2003.

## Other sources for examples

The examples presented above show just a little amount of the full capabilities of PyTables. Please check out the documentation and the `examples/` directory in the source package for more examples.

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »